
# -*- coding: utf-8 -*-
"""Script to get system information.
"""

from __future__ import absolute_import, print_function

import os
import sys
import qdarkstyle

def get_info():
    """Process UI files."""
    info = []
    info.append('QDarkStyle: ', qdarkstyle.__version__)
    info.append('OS: ', sys.platform)
    info.append('Python: ', sys.version)
    info.append('QT_API: ', os.getenv['QT_API'])
    info.append('PYQTGRAPH_QT_LIB: ', os.getenv['PYQTGRAPH_QT_LIB'])
    for item in info:
        print(item)

if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))



#!python
# -*- coding: utf-8 -*-

"""This module provides a main window for UI tests.
"""

import logging
import sys
import argparse
import qdarkstyle

def get_main_window_app(qt_from='pyqt', no_dark=True):
    """Return main window application."""

    # set log for debug
    logging.basicConfig(level=logging.DEBUG)

    style = ''

    if qt_from == 'pyside':
        # using PySide wrapper
        from PySide.QtGui import QApplication, QMainWindow, QDockWidget
        from PySide.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        # getting style
        style = qdarkstyle.load_stylesheet_pyside()

    elif qt_from == 'pyqt':
        # using PyQt4 wrapper
        from PyQt4.QtGui import QApplication, QMainWindow, QDockWidget
        from PyQt4.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        # getting style
        style = qdarkstyle.load_stylesheet_pyqt()

    elif qt_from == 'pyqt5':
        # using PyQt5 wrapper
        from PyQt5.QtWidgets import QApplication, QMainWindow, QDockWidget
        from PyQt5.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        # getting style
        style = qdarkstyle.load_stylesheet_pyqt5()

    elif qt_from == 'qtpy':
        # using QtPy API
        from qtpy.QtWidgets import QApplication, QMainWindow, QDockWidget
        from qtpy.QtCore import QTimer, Qt, QSettings, QByteArray, QPoint, QSize
        # getting style
        style = qdarkstyle.load_stylesheet_from_environment()

    elif qt_from == 'pyqtgraph':
        # using PyQtGraph API
        from pyqtgraph.Qt import QtGui, QtCore
        # getting style
        style = qdarkstyle.load_stylesheet_from_environment(is_pyqtgraph=True)

    if no_dark:
        style = ''

    # create the application
    app = QApplication(sys.argv)
    app.setOrganizationName('QDarkStyle')
    app.setApplicationName('QDarkStyle Test')
    # setup stylesheet
    app.setStyleSheet(style)
    # create main window
    window = QMainWindow()
    window.setWindowTitle("QDarkStyle v." + qdarkstyle.__version__ +
                          " - TEST - Using " + qt_from)
    # auto quit after 2s when testing on travis-ci
    if "--test" in sys.argv:
        QTimer.singleShot(2000, app.exit)
    # run
    window.showMaximized()
    app.exec_()

    return window




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_inputs_fields.ui'
#
# Created by: PyQt5 UI code generator 5.6
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName("DockWidget")
        DockWidget.resize(703, 557)
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.gridLayout = QtWidgets.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 0, 2, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_12.setMinimumSize(QtCore.QSize(0, 0))
        self.label_12.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_12.setFont(font)
        self.label_12.setObjectName("label_12")
        self.gridLayout.addWidget(self.label_12, 1, 0, 1, 1)
        self.fontComboBox = QtWidgets.QFontComboBox(self.dockWidgetContents)
        self.fontComboBox.setMinimumSize(QtCore.QSize(0, 0))
        self.fontComboBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.fontComboBox.setObjectName("fontComboBox")
        self.gridLayout.addWidget(self.fontComboBox, 1, 1, 1, 1)
        self.fontComboBoxDis = QtWidgets.QFontComboBox(self.dockWidgetContents)
        self.fontComboBoxDis.setEnabled(False)
        self.fontComboBoxDis.setMinimumSize(QtCore.QSize(0, 0))
        self.fontComboBoxDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.fontComboBoxDis.setObjectName("fontComboBoxDis")
        self.gridLayout.addWidget(self.fontComboBoxDis, 1, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
        self.comboBoxEdit = QtWidgets.QComboBox(self.dockWidgetContents)
        self.comboBoxEdit.setEditable(True)
        self.comboBoxEdit.setObjectName("comboBoxEdit")
        self.comboBoxEdit.addItem("")
        self.comboBoxEdit.addItem("")
        self.comboBoxEdit.addItem("")
        self.comboBoxEdit.setItemText(2, "")
        self.gridLayout.addWidget(self.comboBoxEdit, 2, 1, 1, 1)
        self.comboBoxEditDis = QtWidgets.QComboBox(self.dockWidgetContents)
        self.comboBoxEditDis.setEnabled(False)
        self.comboBoxEditDis.setEditable(True)
        self.comboBoxEditDis.setObjectName("comboBoxEditDis")
        self.comboBoxEditDis.addItem("")
        self.comboBoxEditDis.addItem("")
        self.comboBoxEditDis.addItem("")
        self.comboBoxEditDis.setItemText(2, "")
        self.gridLayout.addWidget(self.comboBoxEditDis, 2, 2, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_13.setMinimumSize(QtCore.QSize(0, 0))
        self.label_13.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_13.setFont(font)
        self.label_13.setObjectName("label_13")
        self.gridLayout.addWidget(self.label_13, 3, 0, 1, 1)
        self.lineEdit = QtWidgets.QLineEdit(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit.sizePolicy().hasHeightForWidth())
        self.lineEdit.setSizePolicy(sizePolicy)
        self.lineEdit.setMinimumSize(QtCore.QSize(0, 0))
        self.lineEdit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.lineEdit.setObjectName("lineEdit")
        self.gridLayout.addWidget(self.lineEdit, 3, 1, 1, 1)
        self.lineEditDis = QtWidgets.QLineEdit(self.dockWidgetContents)
        self.lineEditDis.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditDis.sizePolicy().hasHeightForWidth())
        self.lineEditDis.setSizePolicy(sizePolicy)
        self.lineEditDis.setMinimumSize(QtCore.QSize(0, 0))
        self.lineEditDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.lineEditDis.setObjectName("lineEditDis")
        self.gridLayout.addWidget(self.lineEditDis, 3, 2, 1, 1)
        self.label_14 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_14.setMinimumSize(QtCore.QSize(0, 0))
        self.label_14.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_14.setFont(font)
        self.label_14.setObjectName("label_14")
        self.gridLayout.addWidget(self.label_14, 4, 0, 1, 1)
        self.textEdit = QtWidgets.QTextEdit(self.dockWidgetContents)
        self.textEdit.setMinimumSize(QtCore.QSize(0, 0))
        self.textEdit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.textEdit.setObjectName("textEdit")
        self.gridLayout.addWidget(self.textEdit, 4, 1, 1, 1)
        self.textEditDis = QtWidgets.QTextEdit(self.dockWidgetContents)
        self.textEditDis.setEnabled(False)
        self.textEditDis.setMinimumSize(QtCore.QSize(0, 0))
        self.textEditDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.textEditDis.setObjectName("textEditDis")
        self.gridLayout.addWidget(self.textEditDis, 4, 2, 1, 1)
        self.label_15 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_15.setMinimumSize(QtCore.QSize(0, 0))
        self.label_15.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_15.setFont(font)
        self.label_15.setObjectName("label_15")
        self.gridLayout.addWidget(self.label_15, 5, 0, 1, 1)
        self.plainTextEdit = QtWidgets.QPlainTextEdit(self.dockWidgetContents)
        self.plainTextEdit.setMinimumSize(QtCore.QSize(0, 0))
        self.plainTextEdit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.plainTextEdit.setObjectName("plainTextEdit")
        self.gridLayout.addWidget(self.plainTextEdit, 5, 1, 1, 1)
        self.plainTextEditDis = QtWidgets.QPlainTextEdit(self.dockWidgetContents)
        self.plainTextEditDis.setEnabled(False)
        self.plainTextEditDis.setMinimumSize(QtCore.QSize(0, 0))
        self.plainTextEditDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.plainTextEditDis.setObjectName("plainTextEditDis")
        self.gridLayout.addWidget(self.plainTextEditDis, 5, 2, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_16.setMinimumSize(QtCore.QSize(0, 0))
        self.label_16.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_16.setFont(font)
        self.label_16.setObjectName("label_16")
        self.gridLayout.addWidget(self.label_16, 6, 0, 1, 1)
        self.spinBox = QtWidgets.QSpinBox(self.dockWidgetContents)
        self.spinBox.setMinimumSize(QtCore.QSize(0, 0))
        self.spinBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.spinBox.setObjectName("spinBox")
        self.gridLayout.addWidget(self.spinBox, 6, 1, 1, 1)
        self.spinBoxDis = QtWidgets.QSpinBox(self.dockWidgetContents)
        self.spinBoxDis.setEnabled(False)
        self.spinBoxDis.setMinimumSize(QtCore.QSize(0, 0))
        self.spinBoxDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.spinBoxDis.setObjectName("spinBoxDis")
        self.gridLayout.addWidget(self.spinBoxDis, 6, 2, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_17.setMinimumSize(QtCore.QSize(0, 0))
        self.label_17.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_17.setFont(font)
        self.label_17.setObjectName("label_17")
        self.gridLayout.addWidget(self.label_17, 7, 0, 1, 1)
        self.doubleSpinBox = QtWidgets.QDoubleSpinBox(self.dockWidgetContents)
        self.doubleSpinBox.setMinimumSize(QtCore.QSize(0, 0))
        self.doubleSpinBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.doubleSpinBox.setObjectName("doubleSpinBox")
        self.gridLayout.addWidget(self.doubleSpinBox, 7, 1, 1, 1)
        self.doubleSpinBoxDis = QtWidgets.QDoubleSpinBox(self.dockWidgetContents)
        self.doubleSpinBoxDis.setEnabled(False)
        self.doubleSpinBoxDis.setMinimumSize(QtCore.QSize(0, 0))
        self.doubleSpinBoxDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.doubleSpinBoxDis.setObjectName("doubleSpinBoxDis")
        self.gridLayout.addWidget(self.doubleSpinBoxDis, 7, 2, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_18.setMinimumSize(QtCore.QSize(0, 0))
        self.label_18.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_18.setFont(font)
        self.label_18.setObjectName("label_18")
        self.gridLayout.addWidget(self.label_18, 8, 0, 1, 1)
        self.timeEdit = QtWidgets.QTimeEdit(self.dockWidgetContents)
        self.timeEdit.setMinimumSize(QtCore.QSize(0, 0))
        self.timeEdit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.timeEdit.setObjectName("timeEdit")
        self.gridLayout.addWidget(self.timeEdit, 8, 1, 1, 1)
        self.timeEditDis = QtWidgets.QTimeEdit(self.dockWidgetContents)
        self.timeEditDis.setEnabled(False)
        self.timeEditDis.setMinimumSize(QtCore.QSize(0, 0))
        self.timeEditDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.timeEditDis.setObjectName("timeEditDis")
        self.gridLayout.addWidget(self.timeEditDis, 8, 2, 1, 1)
        self.label_19 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_19.setMinimumSize(QtCore.QSize(0, 0))
        self.label_19.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_19.setFont(font)
        self.label_19.setObjectName("label_19")
        self.gridLayout.addWidget(self.label_19, 9, 0, 1, 1)
        self.dateEdit = QtWidgets.QDateEdit(self.dockWidgetContents)
        self.dateEdit.setMinimumSize(QtCore.QSize(0, 0))
        self.dateEdit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.dateEdit.setObjectName("dateEdit")
        self.gridLayout.addWidget(self.dateEdit, 9, 1, 1, 1)
        self.dateEditDis = QtWidgets.QDateEdit(self.dockWidgetContents)
        self.dateEditDis.setEnabled(False)
        self.dateEditDis.setMinimumSize(QtCore.QSize(0, 0))
        self.dateEditDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.dateEditDis.setObjectName("dateEditDis")
        self.gridLayout.addWidget(self.dateEditDis, 9, 2, 1, 1)
        self.label_20 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_20.setMinimumSize(QtCore.QSize(0, 0))
        self.label_20.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_20.setFont(font)
        self.label_20.setObjectName("label_20")
        self.gridLayout.addWidget(self.label_20, 10, 0, 1, 1)
        self.dateTimeEdit = QtWidgets.QDateTimeEdit(self.dockWidgetContents)
        self.dateTimeEdit.setMinimumSize(QtCore.QSize(0, 0))
        self.dateTimeEdit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.dateTimeEdit.setObjectName("dateTimeEdit")
        self.gridLayout.addWidget(self.dateTimeEdit, 10, 1, 1, 1)
        self.dateTimeEditDis = QtWidgets.QDateTimeEdit(self.dockWidgetContents)
        self.dateTimeEditDis.setEnabled(False)
        self.dateTimeEditDis.setMinimumSize(QtCore.QSize(0, 0))
        self.dateTimeEditDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.dateTimeEditDis.setObjectName("dateTimeEditDis")
        self.gridLayout.addWidget(self.dateTimeEditDis, 10, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem, 11, 0, 1, 1)
        self.label_51 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_51.setAlignment(QtCore.Qt.AlignCenter)
        self.label_51.setObjectName("label_51")
        self.gridLayout.addWidget(self.label_51, 12, 0, 1, 3)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        self.fontComboBox.editTextChanged['QString'].connect(self.fontComboBoxDis.setEditText)
        self.lineEdit.textEdited['QString'].connect(self.lineEditDis.setText)
        self.spinBox.valueChanged['int'].connect(self.spinBoxDis.setValue)
        self.doubleSpinBox.valueChanged['double'].connect(self.doubleSpinBoxDis.setValue)
        self.timeEdit.timeChanged['QTime'].connect(self.timeEditDis.setTime)
        self.dateEdit.dateTimeChanged['QDateTime'].connect(self.dateEditDis.setDateTime)
        self.dateTimeEdit.dateTimeChanged['QDateTime'].connect(self.dateTimeEditDis.setDateTime)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        _translate = QtCore.QCoreApplication.translate
        DockWidget.setWindowTitle(_translate("DockWidget", "Inputs - Fields"))
        self.label.setText(_translate("DockWidget", "Enabled"))
        self.label_2.setText(_translate("DockWidget", "Disabled"))
        self.label_12.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_12.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_12.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_12.setText(_translate("DockWidget", "FontComboBox"))
        self.fontComboBox.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.fontComboBox.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.fontComboBox.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.fontComboBoxDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.fontComboBoxDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.fontComboBoxDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_3.setText(_translate("DockWidget", "<html><head/><body><p><span style=\" font-weight:600;\">ComboBox</span></p></body></html>"))
        self.comboBoxEdit.setItemText(0, _translate("DockWidget", "ComboBoxEditable"))
        self.comboBoxEdit.setItemText(1, _translate("DockWidget", "Second option"))
        self.comboBoxEditDis.setItemText(0, _translate("DockWidget", "ComboBoxEditable"))
        self.comboBoxEditDis.setItemText(1, _translate("DockWidget", "Second option"))
        self.label_13.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_13.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_13.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_13.setText(_translate("DockWidget", "LineEdit"))
        self.lineEdit.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.lineEdit.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.lineEdit.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.lineEdit.setText(_translate("DockWidget", "LineEdit"))
        self.lineEditDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.lineEditDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.lineEditDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.lineEditDis.setText(_translate("DockWidget", "LineEdit"))
        self.label_14.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_14.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_14.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_14.setText(_translate("DockWidget", "TextEdit"))
        self.textEdit.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.textEdit.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.textEdit.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.textEdit.setHtml(_translate("DockWidget", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Cantarell\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">TextEdit</p></body></html>"))
        self.textEditDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.textEditDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.textEditDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.textEditDis.setHtml(_translate("DockWidget", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Cantarell\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">TextEdit</p></body></html>"))
        self.label_15.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_15.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_15.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_15.setText(_translate("DockWidget", "PlainTextEdit"))
        self.plainTextEdit.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.plainTextEdit.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.plainTextEdit.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.plainTextEdit.setPlainText(_translate("DockWidget", "PlainTextEdit"))
        self.plainTextEditDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.plainTextEditDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.plainTextEditDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.plainTextEditDis.setPlainText(_translate("DockWidget", "PlainTextEdit"))
        self.label_16.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_16.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_16.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_16.setText(_translate("DockWidget", "SpinBox"))
        self.spinBox.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.spinBox.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.spinBox.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.spinBoxDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.spinBoxDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.spinBoxDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_17.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_17.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_17.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_17.setText(_translate("DockWidget", "DoubleSpinBox"))
        self.doubleSpinBox.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.doubleSpinBox.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.doubleSpinBox.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.doubleSpinBoxDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.doubleSpinBoxDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.doubleSpinBoxDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_18.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_18.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_18.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_18.setText(_translate("DockWidget", "TimeEdit"))
        self.timeEdit.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.timeEdit.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.timeEdit.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.timeEditDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.timeEditDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.timeEditDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_19.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_19.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_19.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_19.setText(_translate("DockWidget", "DateEdit"))
        self.dateEdit.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.dateEdit.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.dateEdit.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.dateEditDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.dateEditDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.dateEditDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_20.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_20.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_20.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_20.setText(_translate("DockWidget", "TimeDateEdit"))
        self.dateTimeEdit.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.dateTimeEdit.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.dateTimeEdit.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.dateTimeEditDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.dateTimeEditDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.dateTimeEditDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_51.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_51.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_51.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_51.setText(_translate("DockWidget", "Inside DockWidget"))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_containers_no_tabs.ui'
#
# Created: Thu Dec 13 17:14:05 2018
#      by: pyside2-uic 2.0.0 running on PySide2 5.6.0~a1
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName("DockWidget")
        DockWidget.resize(497, 566)
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.gridLayout_45 = QtWidgets.QGridLayout(self.dockWidgetContents)
        self.gridLayout_45.setObjectName("gridLayout_45")
        self.label_126 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_126.setFont(font)
        self.label_126.setObjectName("label_126")
        self.gridLayout_45.addWidget(self.label_126, 0, 3, 2, 1)
        self.label_124 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_124.setFont(font)
        self.label_124.setObjectName("label_124")
        self.gridLayout_45.addWidget(self.label_124, 0, 2, 2, 1)
        self.label_133 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_133.setFont(font)
        self.label_133.setObjectName("label_133")
        self.gridLayout_45.addWidget(self.label_133, 8, 0, 1, 2)
        self.groupBoxDis_2 = QtWidgets.QGroupBox(self.dockWidgetContents)
        self.groupBoxDis_2.setEnabled(False)
        self.groupBoxDis_2.setObjectName("groupBoxDis_2")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.groupBoxDis_2)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.label_7 = QtWidgets.QLabel(self.groupBoxDis_2)
        self.label_7.setObjectName("label_7")
        self.verticalLayout_4.addWidget(self.label_7)
        self.gridLayout_45.addWidget(self.groupBoxDis_2, 2, 3, 1, 1)
        self.stackedWidget_2 = QtWidgets.QStackedWidget(self.dockWidgetContents)
        self.stackedWidget_2.setObjectName("stackedWidget_2")
        self.page1_2 = QtWidgets.QWidget()
        self.page1_2.setObjectName("page1_2")
        self.gridLayout_35 = QtWidgets.QGridLayout(self.page1_2)
        self.gridLayout_35.setObjectName("gridLayout_35")
        self.label_57 = QtWidgets.QLabel(self.page1_2)
        self.label_57.setObjectName("label_57")
        self.gridLayout_35.addWidget(self.label_57, 0, 0, 1, 1)
        self.stackedWidget_2.addWidget(self.page1_2)
        self.page2_2 = QtWidgets.QWidget()
        self.page2_2.setObjectName("page2_2")
        self.gridLayout_36 = QtWidgets.QGridLayout(self.page2_2)
        self.gridLayout_36.setObjectName("gridLayout_36")
        self.label_58 = QtWidgets.QLabel(self.page2_2)
        self.label_58.setObjectName("label_58")
        self.gridLayout_36.addWidget(self.label_58, 0, 0, 1, 1)
        self.stackedWidget_2.addWidget(self.page2_2)
        self.gridLayout_45.addWidget(self.stackedWidget_2, 5, 2, 1, 1)
        self.stackedWidgetDis_2 = QtWidgets.QStackedWidget(self.dockWidgetContents)
        self.stackedWidgetDis_2.setEnabled(False)
        self.stackedWidgetDis_2.setObjectName("stackedWidgetDis_2")
        self.page1Dis_2 = QtWidgets.QWidget()
        self.page1Dis_2.setObjectName("page1Dis_2")
        self.gridLayout_37 = QtWidgets.QGridLayout(self.page1Dis_2)
        self.gridLayout_37.setObjectName("gridLayout_37")
        self.label_113 = QtWidgets.QLabel(self.page1Dis_2)
        self.label_113.setObjectName("label_113")
        self.gridLayout_37.addWidget(self.label_113, 0, 0, 1, 1)
        self.stackedWidgetDis_2.addWidget(self.page1Dis_2)
        self.page2Dis_2 = QtWidgets.QWidget()
        self.page2Dis_2.setObjectName("page2Dis_2")
        self.gridLayout_38 = QtWidgets.QGridLayout(self.page2Dis_2)
        self.gridLayout_38.setObjectName("gridLayout_38")
        self.label_114 = QtWidgets.QLabel(self.page2Dis_2)
        self.label_114.setObjectName("label_114")
        self.gridLayout_38.addWidget(self.label_114, 0, 0, 1, 1)
        self.stackedWidgetDis_2.addWidget(self.page2Dis_2)
        self.gridLayout_45.addWidget(self.stackedWidgetDis_2, 5, 3, 1, 1)
        self.label_131 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_131.setFont(font)
        self.label_131.setObjectName("label_131")
        self.gridLayout_45.addWidget(self.label_131, 6, 0, 1, 1)
        self.frame_2 = QtWidgets.QFrame(self.dockWidgetContents)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.gridLayout_43 = QtWidgets.QGridLayout(self.frame_2)
        self.gridLayout_43.setObjectName("gridLayout_43")
        self.label_9 = QtWidgets.QLabel(self.frame_2)
        self.label_9.setObjectName("label_9")
        self.gridLayout_43.addWidget(self.label_9, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.frame_2, 6, 2, 1, 1)
        self.frameDis_2 = QtWidgets.QFrame(self.dockWidgetContents)
        self.frameDis_2.setEnabled(False)
        self.frameDis_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frameDis_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frameDis_2.setObjectName("frameDis_2")
        self.gridLayout_40 = QtWidgets.QGridLayout(self.frameDis_2)
        self.gridLayout_40.setObjectName("gridLayout_40")
        self.label_8 = QtWidgets.QLabel(self.frameDis_2)
        self.label_8.setObjectName("label_8")
        self.gridLayout_40.addWidget(self.label_8, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.frameDis_2, 6, 3, 1, 1)
        self.label_132 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_132.setFont(font)
        self.label_132.setObjectName("label_132")
        self.gridLayout_45.addWidget(self.label_132, 7, 0, 1, 2)
        self.groupBox_2 = QtWidgets.QGroupBox(self.dockWidgetContents)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.label_10 = QtWidgets.QLabel(self.groupBox_2)
        self.label_10.setObjectName("label_10")
        self.gridLayout_7.addWidget(self.label_10, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.groupBox_2, 2, 2, 1, 1)
        self.mdiAreaDis_2 = QtWidgets.QMdiArea(self.dockWidgetContents)
        self.mdiAreaDis_2.setEnabled(False)
        self.mdiAreaDis_2.setObjectName("mdiAreaDis_2")
        self.subwindow1Dis_2 = QtWidgets.QWidget()
        self.subwindow1Dis_2.setObjectName("subwindow1Dis_2")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.subwindow1Dis_2)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.label_111 = QtWidgets.QLabel(self.subwindow1Dis_2)
        self.label_111.setObjectName("label_111")
        self.verticalLayout_9.addWidget(self.label_111)
        self.subwindow2Dis_2 = QtWidgets.QWidget()
        self.subwindow2Dis_2.setObjectName("subwindow2Dis_2")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.subwindow2Dis_2)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.label_112 = QtWidgets.QLabel(self.subwindow2Dis_2)
        self.label_112.setObjectName("label_112")
        self.verticalLayout_10.addWidget(self.label_112)
        self.gridLayout_45.addWidget(self.mdiAreaDis_2, 8, 3, 1, 1)
        self.label_127 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_127.setFont(font)
        self.label_127.setObjectName("label_127")
        self.gridLayout_45.addWidget(self.label_127, 2, 0, 1, 2)
        self.widget_2 = QtWidgets.QWidget(self.dockWidgetContents)
        self.widget_2.setObjectName("widget_2")
        self.gridLayout_39 = QtWidgets.QGridLayout(self.widget_2)
        self.gridLayout_39.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_39.setObjectName("gridLayout_39")
        self.label_59 = QtWidgets.QLabel(self.widget_2)
        self.label_59.setObjectName("label_59")
        self.gridLayout_39.addWidget(self.label_59, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.widget_2, 7, 2, 1, 1)
        self.widgetDis_2 = QtWidgets.QWidget(self.dockWidgetContents)
        self.widgetDis_2.setEnabled(False)
        self.widgetDis_2.setObjectName("widgetDis_2")
        self.gridLayout_44 = QtWidgets.QGridLayout(self.widgetDis_2)
        self.gridLayout_44.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_44.setObjectName("gridLayout_44")
        self.label_125 = QtWidgets.QLabel(self.widgetDis_2)
        self.label_125.setObjectName("label_125")
        self.gridLayout_44.addWidget(self.label_125, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.widgetDis_2, 7, 3, 1, 1)
        self.mdiArea_2 = QtWidgets.QMdiArea(self.dockWidgetContents)
        self.mdiArea_2.setObjectName("mdiArea_2")
        self.subwindow1_2 = QtWidgets.QWidget()
        self.subwindow1_2.setObjectName("subwindow1_2")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.subwindow1_2)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.label_29 = QtWidgets.QLabel(self.subwindow1_2)
        self.label_29.setObjectName("label_29")
        self.verticalLayout_11.addWidget(self.label_29)
        self.subwindow2_2 = QtWidgets.QWidget()
        self.subwindow2_2.setObjectName("subwindow2_2")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.subwindow2_2)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.label_56 = QtWidgets.QLabel(self.subwindow2_2)
        self.label_56.setObjectName("label_56")
        self.verticalLayout_12.addWidget(self.label_56)
        self.gridLayout_45.addWidget(self.mdiArea_2, 8, 2, 1, 1)
        self.label_128 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_128.setFont(font)
        self.label_128.setObjectName("label_128")
        self.gridLayout_45.addWidget(self.label_128, 3, 0, 1, 2)
        self.scrollArea_2 = QtWidgets.QScrollArea(self.dockWidgetContents)
        self.scrollArea_2.setWidgetResizable(True)
        self.scrollArea_2.setObjectName("scrollArea_2")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 181, 246))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_2)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.label_70 = QtWidgets.QLabel(self.scrollAreaWidgetContents_2)
        self.label_70.setObjectName("label_70")
        self.verticalLayout_14.addWidget(self.label_70)
        self.label_71 = QtWidgets.QLabel(self.scrollAreaWidgetContents_2)
        self.label_71.setObjectName("label_71")
        self.verticalLayout_14.addWidget(self.label_71)
        self.label_75 = QtWidgets.QLabel(self.scrollAreaWidgetContents_2)
        self.label_75.setObjectName("label_75")
        self.verticalLayout_14.addWidget(self.label_75)
        self.label_76 = QtWidgets.QLabel(self.scrollAreaWidgetContents_2)
        self.label_76.setObjectName("label_76")
        self.verticalLayout_14.addWidget(self.label_76)
        self.label_77 = QtWidgets.QLabel(self.scrollAreaWidgetContents_2)
        self.label_77.setObjectName("label_77")
        self.verticalLayout_14.addWidget(self.label_77)
        self.label_78 = QtWidgets.QLabel(self.scrollAreaWidgetContents_2)
        self.label_78.setObjectName("label_78")
        self.verticalLayout_14.addWidget(self.label_78)
        self.label_79 = QtWidgets.QLabel(self.scrollAreaWidgetContents_2)
        self.label_79.setObjectName("label_79")
        self.verticalLayout_14.addWidget(self.label_79)
        self.label_80 = QtWidgets.QLabel(self.scrollAreaWidgetContents_2)
        self.label_80.setObjectName("label_80")
        self.verticalLayout_14.addWidget(self.label_80)
        self.label_81 = QtWidgets.QLabel(self.scrollAreaWidgetContents_2)
        self.label_81.setObjectName("label_81")
        self.verticalLayout_14.addWidget(self.label_81)
        self.scrollArea_2.setWidget(self.scrollAreaWidgetContents_2)
        self.gridLayout_45.addWidget(self.scrollArea_2, 3, 2, 1, 1)
        self.scrollAreaDis_2 = QtWidgets.QScrollArea(self.dockWidgetContents)
        self.scrollAreaDis_2.setEnabled(False)
        self.scrollAreaDis_2.setWidgetResizable(True)
        self.scrollAreaDis_2.setObjectName("scrollAreaDis_2")
        self.scrollAreaWidgetContentsDis_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContentsDis_2.setGeometry(QtCore.QRect(0, 0, 181, 246))
        self.scrollAreaWidgetContentsDis_2.setObjectName("scrollAreaWidgetContentsDis_2")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContentsDis_2)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.label_115 = QtWidgets.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_115.setObjectName("label_115")
        self.verticalLayout_13.addWidget(self.label_115)
        self.label_116 = QtWidgets.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_116.setObjectName("label_116")
        self.verticalLayout_13.addWidget(self.label_116)
        self.label_117 = QtWidgets.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_117.setObjectName("label_117")
        self.verticalLayout_13.addWidget(self.label_117)
        self.label_118 = QtWidgets.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_118.setObjectName("label_118")
        self.verticalLayout_13.addWidget(self.label_118)
        self.label_119 = QtWidgets.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_119.setObjectName("label_119")
        self.verticalLayout_13.addWidget(self.label_119)
        self.label_120 = QtWidgets.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_120.setObjectName("label_120")
        self.verticalLayout_13.addWidget(self.label_120)
        self.label_121 = QtWidgets.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_121.setObjectName("label_121")
        self.verticalLayout_13.addWidget(self.label_121)
        self.label_122 = QtWidgets.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_122.setObjectName("label_122")
        self.verticalLayout_13.addWidget(self.label_122)
        self.label_123 = QtWidgets.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_123.setObjectName("label_123")
        self.verticalLayout_13.addWidget(self.label_123)
        self.scrollAreaDis_2.setWidget(self.scrollAreaWidgetContentsDis_2)
        self.gridLayout_45.addWidget(self.scrollAreaDis_2, 3, 3, 1, 1)
        self.label_129 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_129.setFont(font)
        self.label_129.setObjectName("label_129")
        self.gridLayout_45.addWidget(self.label_129, 4, 0, 1, 2)
        self.toolBox_2 = QtWidgets.QToolBox(self.dockWidgetContents)
        self.toolBox_2.setObjectName("toolBox_2")
        self.page_3 = QtWidgets.QWidget()
        self.page_3.setGeometry(QtCore.QRect(0, 0, 196, 73))
        self.page_3.setObjectName("page_3")
        self.gridLayout_41 = QtWidgets.QGridLayout(self.page_3)
        self.gridLayout_41.setObjectName("gridLayout_41")
        self.label_60 = QtWidgets.QLabel(self.page_3)
        self.label_60.setObjectName("label_60")
        self.gridLayout_41.addWidget(self.label_60, 2, 0, 1, 1)
        self.toolBox_2.addItem(self.page_3, "")
        self.page_8 = QtWidgets.QWidget()
        self.page_8.setGeometry(QtCore.QRect(0, 0, 163, 38))
        self.page_8.setObjectName("page_8")
        self.gridLayout_42 = QtWidgets.QGridLayout(self.page_8)
        self.gridLayout_42.setObjectName("gridLayout_42")
        self.label_61 = QtWidgets.QLabel(self.page_8)
        self.label_61.setObjectName("label_61")
        self.gridLayout_42.addWidget(self.label_61, 0, 0, 1, 1)
        self.toolBox_2.addItem(self.page_8, "")
        self.gridLayout_45.addWidget(self.toolBox_2, 4, 2, 1, 1)
        self.toolBoxDis_2 = QtWidgets.QToolBox(self.dockWidgetContents)
        self.toolBoxDis_2.setEnabled(False)
        self.toolBoxDis_2.setObjectName("toolBoxDis_2")
        self.page_6 = QtWidgets.QWidget()
        self.page_6.setGeometry(QtCore.QRect(0, 0, 196, 73))
        self.page_6.setObjectName("page_6")
        self.gridLayout_29 = QtWidgets.QGridLayout(self.page_6)
        self.gridLayout_29.setObjectName("gridLayout_29")
        self.label_109 = QtWidgets.QLabel(self.page_6)
        self.label_109.setObjectName("label_109")
        self.gridLayout_29.addWidget(self.label_109, 2, 0, 1, 1)
        self.toolBoxDis_2.addItem(self.page_6, "")
        self.page_7 = QtWidgets.QWidget()
        self.page_7.setGeometry(QtCore.QRect(0, 0, 163, 38))
        self.page_7.setObjectName("page_7")
        self.gridLayout_34 = QtWidgets.QGridLayout(self.page_7)
        self.gridLayout_34.setObjectName("gridLayout_34")
        self.label_110 = QtWidgets.QLabel(self.page_7)
        self.label_110.setObjectName("label_110")
        self.gridLayout_34.addWidget(self.label_110, 0, 0, 1, 1)
        self.toolBoxDis_2.addItem(self.page_7, "")
        self.gridLayout_45.addWidget(self.toolBoxDis_2, 4, 3, 1, 1)
        self.label_130 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_130.setFont(font)
        self.label_130.setObjectName("label_130")
        self.gridLayout_45.addWidget(self.label_130, 5, 0, 1, 2)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        self.stackedWidget_2.setCurrentIndex(1)
        self.stackedWidgetDis_2.setCurrentIndex(1)
        self.toolBox_2.setCurrentIndex(0)
        self.toolBoxDis_2.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(QtWidgets.QApplication.translate("DockWidget", "Containers - No Tabs", None, -1))
        self.label_126.setText(QtWidgets.QApplication.translate("DockWidget", "Disabled", None, -1))
        self.label_124.setText(QtWidgets.QApplication.translate("DockWidget", "Enabled", None, -1))
        self.label_133.setText(QtWidgets.QApplication.translate("DockWidget", "MDI Area", None, -1))
        self.groupBoxDis_2.setTitle(QtWidgets.QApplication.translate("DockWidget", "GroupBox", None, -1))
        self.label_7.setText(QtWidgets.QApplication.translate("DockWidget", "Inside GroupBox", None, -1))
        self.stackedWidget_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.stackedWidget_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.stackedWidget_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_57.setText(QtWidgets.QApplication.translate("DockWidget", "Inside Stacked Page 1", None, -1))
        self.label_58.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_58.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_58.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_58.setText(QtWidgets.QApplication.translate("DockWidget", "Inside Stacked Page 2", None, -1))
        self.stackedWidgetDis_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.stackedWidgetDis_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.stackedWidgetDis_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_113.setText(QtWidgets.QApplication.translate("DockWidget", "Inside Stacked Page 1", None, -1))
        self.label_114.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_114.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_114.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_114.setText(QtWidgets.QApplication.translate("DockWidget", "Inside Stacked Page 2", None, -1))
        self.label_131.setText(QtWidgets.QApplication.translate("DockWidget", "Frame", None, -1))
        self.frame_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.frame_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.frame_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_9.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_9.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_9.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_9.setText(QtWidgets.QApplication.translate("DockWidget", "Inside Frame", None, -1))
        self.frameDis_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.frameDis_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.frameDis_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_8.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_8.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_8.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_8.setText(QtWidgets.QApplication.translate("DockWidget", "Inside Frame", None, -1))
        self.label_132.setText(QtWidgets.QApplication.translate("DockWidget", "Widget", None, -1))
        self.groupBox_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.groupBox_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.groupBox_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.groupBox_2.setTitle(QtWidgets.QApplication.translate("DockWidget", "GroupBox", None, -1))
        self.label_10.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_10.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_10.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_10.setText(QtWidgets.QApplication.translate("DockWidget", "Inside GroupBox", None, -1))
        self.subwindow1Dis_2.setWindowTitle(QtWidgets.QApplication.translate("DockWidget", "Subwindow", None, -1))
        self.label_111.setText(QtWidgets.QApplication.translate("DockWidget", "Inside MDI Area 1", None, -1))
        self.subwindow2Dis_2.setWindowTitle(QtWidgets.QApplication.translate("DockWidget", "Subwindow", None, -1))
        self.label_112.setText(QtWidgets.QApplication.translate("DockWidget", "Inside MDI Area 2 ", None, -1))
        self.label_127.setText(QtWidgets.QApplication.translate("DockWidget", "GroupBox", None, -1))
        self.widget_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.widget_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.widget_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_59.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_59.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_59.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_59.setText(QtWidgets.QApplication.translate("DockWidget", "Inside Widget", None, -1))
        self.widgetDis_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.widgetDis_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.widgetDis_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_125.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_125.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_125.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_125.setText(QtWidgets.QApplication.translate("DockWidget", "Inside Widget", None, -1))
        self.subwindow1_2.setWindowTitle(QtWidgets.QApplication.translate("DockWidget", "Subwindow", None, -1))
        self.label_29.setText(QtWidgets.QApplication.translate("DockWidget", "Inside MDI Area 1", None, -1))
        self.subwindow2_2.setWindowTitle(QtWidgets.QApplication.translate("DockWidget", "Subwindow", None, -1))
        self.label_56.setText(QtWidgets.QApplication.translate("DockWidget", "Inside MDI Area 2 ", None, -1))
        self.label_128.setText(QtWidgets.QApplication.translate("DockWidget", "ScroolArea", None, -1))
        self.scrollArea_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.scrollArea_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.scrollArea_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_70.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_70.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_70.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_70.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea", None, -1))
        self.label_71.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_71.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_71.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_71.setText(QtWidgets.QApplication.translate("DockWidget", "ScroolArea ", None, -1))
        self.label_75.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_75.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_75.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_75.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea ", None, -1))
        self.label_76.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_76.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_76.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_76.setText(QtWidgets.QApplication.translate("DockWidget", "ScroolArea", None, -1))
        self.label_77.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_77.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_77.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_77.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea", None, -1))
        self.label_78.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_78.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_78.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_78.setText(QtWidgets.QApplication.translate("DockWidget", "ScroolArea", None, -1))
        self.label_79.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_79.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_79.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_79.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea", None, -1))
        self.label_80.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_80.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_80.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_80.setText(QtWidgets.QApplication.translate("DockWidget", "ScroolArea", None, -1))
        self.label_81.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_81.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_81.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_81.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea", None, -1))
        self.scrollAreaDis_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.scrollAreaDis_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.scrollAreaDis_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_115.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_115.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_115.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_115.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea", None, -1))
        self.label_116.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_116.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_116.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_116.setText(QtWidgets.QApplication.translate("DockWidget", "ScroolArea ", None, -1))
        self.label_117.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_117.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_117.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_117.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea ", None, -1))
        self.label_118.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_118.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_118.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_118.setText(QtWidgets.QApplication.translate("DockWidget", "ScroolArea", None, -1))
        self.label_119.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_119.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_119.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_119.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea", None, -1))
        self.label_120.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_120.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_120.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_120.setText(QtWidgets.QApplication.translate("DockWidget", "ScroolArea", None, -1))
        self.label_121.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_121.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_121.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_121.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea", None, -1))
        self.label_122.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_122.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_122.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_122.setText(QtWidgets.QApplication.translate("DockWidget", "ScroolArea", None, -1))
        self.label_123.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_123.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_123.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_123.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ScroolArea", None, -1))
        self.label_129.setText(QtWidgets.QApplication.translate("DockWidget", "ToolBox", None, -1))
        self.toolBox_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.toolBox_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.toolBox_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_60.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ToolBox Page 1", None, -1))
        self.toolBox_2.setItemText(self.toolBox_2.indexOf(self.page_3), QtWidgets.QApplication.translate("DockWidget", "Page 1", None, -1))
        self.label_61.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_61.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_61.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_61.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ToolBox Page 2", None, -1))
        self.toolBox_2.setItemText(self.toolBox_2.indexOf(self.page_8), QtWidgets.QApplication.translate("DockWidget", "Page 2", None, -1))
        self.toolBoxDis_2.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.toolBoxDis_2.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.toolBoxDis_2.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_109.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ToolBox Page 1", None, -1))
        self.toolBoxDis_2.setItemText(self.toolBoxDis_2.indexOf(self.page_6), QtWidgets.QApplication.translate("DockWidget", "Page 1", None, -1))
        self.label_110.setToolTip(QtWidgets.QApplication.translate("DockWidget", "This is a tool tip", None, -1))
        self.label_110.setStatusTip(QtWidgets.QApplication.translate("DockWidget", "This is a status tip", None, -1))
        self.label_110.setWhatsThis(QtWidgets.QApplication.translate("DockWidget", "This is \"what is this\"", None, -1))
        self.label_110.setText(QtWidgets.QApplication.translate("DockWidget", "Inside ToolBox Page 2", None, -1))
        self.toolBoxDis_2.setItemText(self.toolBoxDis_2.indexOf(self.page_7), QtWidgets.QApplication.translate("DockWidget", "Page 2", None, -1))
        self.label_130.setText(QtWidgets.QApplication.translate("DockWidget", "Stacked", None, -1))




#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
from qdarkstyle import __version__
from qdarkstyle import __doc__ as long_desc

setup(
    name='QDarkStyle',
    version=__version__,
    packages=find_packages(),
    url='https://github.com/ColinDuquesnoy/QDarkStyleSheet',
    license='MIT',
    author='Colin Duquesnoy',
    author_email='colin.duquesnoy@gmail.com',
    description='A dark stylesheet for Python and Qt applications',
    long_description=long_desc,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: X11 Applications :: Qt',
        'Environment :: Win32 (MS Windows)',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX :: Linux',
        'Operating System :: MacOS',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries :: Application Frameworks'
    ],
    zip_safe=False,  # don't use eggs
    entry_points={"console_scripts": ["qdarkstyle=qdarkstyle.__main__:main"]}
)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_buttons.ui'
#
# Created by: PyQt5 UI code generator 5.6
#
# WARNING! All changes made in this file will be lost!

from qtpy import QtCore, QtGui, QtWidgets

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName("DockWidget")
        DockWidget.resize(527, 460)
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.gridLayout = QtWidgets.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.label_72 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_72.setFont(font)
        self.label_72.setObjectName("label_72")
        self.gridLayout.addWidget(self.label_72, 0, 1, 1, 1)
        self.label_73 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_73.setFont(font)
        self.label_73.setObjectName("label_73")
        self.gridLayout.addWidget(self.label_73, 0, 2, 1, 1)
        self.label_26 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_26.setMinimumSize(QtCore.QSize(0, 0))
        self.label_26.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_26.setFont(font)
        self.label_26.setObjectName("label_26")
        self.gridLayout.addWidget(self.label_26, 1, 0, 1, 1)
        self.pushButton = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButton.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButton.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButton.setObjectName("pushButton")
        self.gridLayout.addWidget(self.pushButton, 1, 1, 1, 1)
        self.pushButtonDis = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButtonDis.setEnabled(False)
        self.pushButtonDis.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButtonDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButtonDis.setDefault(False)
        self.pushButtonDis.setObjectName("pushButtonDis")
        self.gridLayout.addWidget(self.pushButtonDis, 1, 2, 1, 1)
        self.label_74 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_74.setFont(font)
        self.label_74.setObjectName("label_74")
        self.gridLayout.addWidget(self.label_74, 2, 0, 1, 1)
        self.pushButtonChecked = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButtonChecked.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButtonChecked.setCheckable(True)
        self.pushButtonChecked.setChecked(True)
        self.pushButtonChecked.setObjectName("pushButtonChecked")
        self.gridLayout.addWidget(self.pushButtonChecked, 2, 1, 1, 1)
        self.pushButtonCheckedDis = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButtonCheckedDis.setEnabled(False)
        self.pushButtonCheckedDis.setCheckable(True)
        self.pushButtonCheckedDis.setChecked(True)
        self.pushButtonCheckedDis.setObjectName("pushButtonCheckedDis")
        self.gridLayout.addWidget(self.pushButtonCheckedDis, 2, 2, 1, 1)
        self.label_76 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_76.setFont(font)
        self.label_76.setObjectName("label_76")
        self.gridLayout.addWidget(self.label_76, 3, 0, 1, 1)
        self.pushButtonUnchecked = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButtonUnchecked.setCheckable(True)
        self.pushButtonUnchecked.setObjectName("pushButtonUnchecked")
        self.gridLayout.addWidget(self.pushButtonUnchecked, 3, 1, 1, 1)
        self.pushButtonUncheckedDis = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButtonUncheckedDis.setEnabled(False)
        self.pushButtonUncheckedDis.setCheckable(True)
        self.pushButtonUncheckedDis.setObjectName("pushButtonUncheckedDis")
        self.gridLayout.addWidget(self.pushButtonUncheckedDis, 3, 2, 1, 1)
        self.label_33 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_33.setMinimumSize(QtCore.QSize(0, 0))
        self.label_33.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_33.setFont(font)
        self.label_33.setObjectName("label_33")
        self.gridLayout.addWidget(self.label_33, 4, 0, 1, 1)
        self.toolButton = QtWidgets.QToolButton(self.dockWidgetContents)
        self.toolButton.setMinimumSize(QtCore.QSize(0, 0))
        self.toolButton.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.toolButton.setObjectName("toolButton")
        self.gridLayout.addWidget(self.toolButton, 4, 1, 1, 1)
        self.toolButtonDis = QtWidgets.QToolButton(self.dockWidgetContents)
        self.toolButtonDis.setEnabled(False)
        self.toolButtonDis.setMinimumSize(QtCore.QSize(0, 0))
        self.toolButtonDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.toolButtonDis.setObjectName("toolButtonDis")
        self.gridLayout.addWidget(self.toolButtonDis, 4, 2, 1, 1)
        self.label_75 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_75.setFont(font)
        self.label_75.setObjectName("label_75")
        self.gridLayout.addWidget(self.label_75, 5, 0, 1, 1)
        self.radioButtonChecked = QtWidgets.QRadioButton(self.dockWidgetContents)
        self.radioButtonChecked.setChecked(True)
        self.radioButtonChecked.setAutoExclusive(False)
        self.radioButtonChecked.setObjectName("radioButtonChecked")
        self.gridLayout.addWidget(self.radioButtonChecked, 5, 1, 1, 1)
        self.radioButtonCheckedDis = QtWidgets.QRadioButton(self.dockWidgetContents)
        self.radioButtonCheckedDis.setEnabled(False)
        self.radioButtonCheckedDis.setChecked(True)
        self.radioButtonCheckedDis.setAutoExclusive(False)
        self.radioButtonCheckedDis.setObjectName("radioButtonCheckedDis")
        self.gridLayout.addWidget(self.radioButtonCheckedDis, 5, 2, 1, 1)
        self.label_29 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_29.setMinimumSize(QtCore.QSize(0, 0))
        self.label_29.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_29.setFont(font)
        self.label_29.setObjectName("label_29")
        self.gridLayout.addWidget(self.label_29, 6, 0, 1, 1)
        self.radioButtonUnchecked = QtWidgets.QRadioButton(self.dockWidgetContents)
        self.radioButtonUnchecked.setMinimumSize(QtCore.QSize(0, 0))
        self.radioButtonUnchecked.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.radioButtonUnchecked.setAutoExclusive(False)
        self.radioButtonUnchecked.setObjectName("radioButtonUnchecked")
        self.gridLayout.addWidget(self.radioButtonUnchecked, 6, 1, 1, 1)
        self.radioButtonUncheckedDis = QtWidgets.QRadioButton(self.dockWidgetContents)
        self.radioButtonUncheckedDis.setEnabled(False)
        self.radioButtonUncheckedDis.setMinimumSize(QtCore.QSize(0, 0))
        self.radioButtonUncheckedDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.radioButtonUncheckedDis.setChecked(False)
        self.radioButtonUncheckedDis.setAutoExclusive(False)
        self.radioButtonUncheckedDis.setObjectName("radioButtonUncheckedDis")
        self.gridLayout.addWidget(self.radioButtonUncheckedDis, 6, 2, 1, 1)
        self.label_53 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_53.setFont(font)
        self.label_53.setObjectName("label_53")
        self.gridLayout.addWidget(self.label_53, 7, 0, 1, 1)
        self.checkBoxChecked = QtWidgets.QCheckBox(self.dockWidgetContents)
        self.checkBoxChecked.setChecked(True)
        self.checkBoxChecked.setObjectName("checkBoxChecked")
        self.gridLayout.addWidget(self.checkBoxChecked, 7, 1, 1, 1)
        self.checkBoxCheckedDis = QtWidgets.QCheckBox(self.dockWidgetContents)
        self.checkBoxCheckedDis.setEnabled(False)
        self.checkBoxCheckedDis.setChecked(True)
        self.checkBoxCheckedDis.setObjectName("checkBoxCheckedDis")
        self.gridLayout.addWidget(self.checkBoxCheckedDis, 7, 2, 1, 1)
        self.label_30 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_30.setMinimumSize(QtCore.QSize(0, 0))
        self.label_30.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_30.setFont(font)
        self.label_30.setObjectName("label_30")
        self.gridLayout.addWidget(self.label_30, 8, 0, 1, 1)
        self.checkBoxEnabled = QtWidgets.QCheckBox(self.dockWidgetContents)
        self.checkBoxEnabled.setMinimumSize(QtCore.QSize(0, 0))
        self.checkBoxEnabled.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.checkBoxEnabled.setTristate(False)
        self.checkBoxEnabled.setObjectName("checkBoxEnabled")
        self.gridLayout.addWidget(self.checkBoxEnabled, 8, 1, 1, 1)
        self.checkBoxUncheckedDis = QtWidgets.QCheckBox(self.dockWidgetContents)
        self.checkBoxUncheckedDis.setEnabled(False)
        self.checkBoxUncheckedDis.setMinimumSize(QtCore.QSize(0, 0))
        self.checkBoxUncheckedDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.checkBoxUncheckedDis.setChecked(False)
        self.checkBoxUncheckedDis.setObjectName("checkBoxUncheckedDis")
        self.gridLayout.addWidget(self.checkBoxUncheckedDis, 8, 2, 1, 1)
        self.label_31 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_31.setMinimumSize(QtCore.QSize(0, 0))
        self.label_31.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_31.setFont(font)
        self.label_31.setObjectName("label_31")
        self.gridLayout.addWidget(self.label_31, 10, 0, 1, 1)
        self.commandLinkButton = QtWidgets.QCommandLinkButton(self.dockWidgetContents)
        self.commandLinkButton.setMinimumSize(QtCore.QSize(0, 0))
        self.commandLinkButton.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.commandLinkButton.setObjectName("commandLinkButton")
        self.gridLayout.addWidget(self.commandLinkButton, 10, 1, 1, 1)
        self.commandLinkButtonDIs = QtWidgets.QCommandLinkButton(self.dockWidgetContents)
        self.commandLinkButtonDIs.setEnabled(False)
        self.commandLinkButtonDIs.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.commandLinkButtonDIs.setObjectName("commandLinkButtonDIs")
        self.gridLayout.addWidget(self.commandLinkButtonDIs, 10, 2, 1, 1)
        self.label_32 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_32.setMinimumSize(QtCore.QSize(0, 0))
        self.label_32.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_32.setFont(font)
        self.label_32.setObjectName("label_32")
        self.gridLayout.addWidget(self.label_32, 11, 0, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(self.dockWidgetContents)
        self.buttonBox.setMinimumSize(QtCore.QSize(0, 0))
        self.buttonBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 11, 1, 1, 1)
        self.buttonBoxDis = QtWidgets.QDialogButtonBox(self.dockWidgetContents)
        self.buttonBoxDis.setEnabled(False)
        self.buttonBoxDis.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBoxDis.setObjectName("buttonBoxDis")
        self.gridLayout.addWidget(self.buttonBoxDis, 11, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 4, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem, 12, 0, 1, 1)
        self.label_36 = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_36.setAlignment(QtCore.Qt.AlignCenter)
        self.label_36.setObjectName("label_36")
        self.gridLayout.addWidget(self.label_36, 13, 0, 1, 3)
        self.label = QtWidgets.QLabel(self.dockWidgetContents)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 9, 0, 1, 1)
        self.checkBoxTristate = QtWidgets.QCheckBox(self.dockWidgetContents)
        self.checkBoxTristate.setChecked(False)
        self.checkBoxTristate.setTristate(True)
        self.checkBoxTristate.setObjectName("checkBoxTristate")
        self.gridLayout.addWidget(self.checkBoxTristate, 9, 1, 1, 1)
        self.checkBoxTristateDis = QtWidgets.QCheckBox(self.dockWidgetContents)
        self.checkBoxTristateDis.setEnabled(False)
        self.checkBoxTristateDis.setChecked(False)
        self.checkBoxTristateDis.setTristate(True)
        self.checkBoxTristateDis.setObjectName("checkBoxTristateDis")
        self.gridLayout.addWidget(self.checkBoxTristateDis, 9, 2, 1, 1)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        self.radioButtonChecked.clicked['bool'].connect(self.radioButtonCheckedDis.setChecked)
        self.radioButtonUnchecked.clicked['bool'].connect(self.radioButtonUncheckedDis.setChecked)
        self.checkBoxChecked.clicked['bool'].connect(self.checkBoxCheckedDis.setChecked)
        self.checkBoxEnabled.clicked['bool'].connect(self.checkBoxUncheckedDis.setChecked)
        self.checkBoxTristate.clicked['bool'].connect(self.checkBoxTristateDis.setChecked)
        self.commandLinkButton.clicked['bool'].connect(self.commandLinkButtonDIs.setChecked)
        self.toolButton.clicked['bool'].connect(self.toolButtonDis.setChecked)
        self.pushButtonChecked.clicked['bool'].connect(self.pushButtonCheckedDis.setChecked)
        self.pushButtonUnchecked.clicked['bool'].connect(self.pushButtonUncheckedDis.setChecked)
        self.pushButton.clicked['bool'].connect(self.pushButtonDis.click)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        _translate = QtCore.QCoreApplication.translate
        DockWidget.setWindowTitle(_translate("DockWidget", "Buttons"))
        self.label_72.setText(_translate("DockWidget", "Enabled"))
        self.label_73.setText(_translate("DockWidget", "Disabled"))
        self.label_26.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_26.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_26.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_26.setText(_translate("DockWidget", "PushButton"))
        self.pushButton.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.pushButton.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.pushButton.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.pushButton.setText(_translate("DockWidget", "OK"))
        self.pushButtonDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.pushButtonDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.pushButtonDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.pushButtonDis.setText(_translate("DockWidget", "OK"))
        self.label_74.setText(_translate("DockWidget", "PushButton"))
        self.pushButtonChecked.setText(_translate("DockWidget", "Checked"))
        self.pushButtonCheckedDis.setText(_translate("DockWidget", "Checked"))
        self.label_76.setText(_translate("DockWidget", "PushButton"))
        self.pushButtonUnchecked.setText(_translate("DockWidget", "Unchecked"))
        self.pushButtonUncheckedDis.setText(_translate("DockWidget", "Unchecked"))
        self.label_33.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_33.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_33.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_33.setText(_translate("DockWidget", "ToolButton"))
        self.toolButton.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.toolButton.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.toolButton.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.toolButton.setText(_translate("DockWidget", "Tool"))
        self.toolButtonDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.toolButtonDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.toolButtonDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.toolButtonDis.setText(_translate("DockWidget", "Tool"))
        self.label_75.setText(_translate("DockWidget", "RadioButton"))
        self.radioButtonChecked.setText(_translate("DockWidget", "Checked"))
        self.radioButtonCheckedDis.setText(_translate("DockWidget", "Checked"))
        self.label_29.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_29.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_29.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_29.setText(_translate("DockWidget", "RadioButton"))
        self.radioButtonUnchecked.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.radioButtonUnchecked.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.radioButtonUnchecked.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.radioButtonUnchecked.setText(_translate("DockWidget", "Unchecked"))
        self.radioButtonUncheckedDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.radioButtonUncheckedDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.radioButtonUncheckedDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.radioButtonUncheckedDis.setText(_translate("DockWidget", "Unchecked"))
        self.label_53.setText(_translate("DockWidget", "CheckBox"))
        self.checkBoxChecked.setText(_translate("DockWidget", "Checked"))
        self.checkBoxCheckedDis.setText(_translate("DockWidget", "Checked"))
        self.label_30.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_30.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_30.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_30.setText(_translate("DockWidget", "CheckBox"))
        self.checkBoxEnabled.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.checkBoxEnabled.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.checkBoxEnabled.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.checkBoxEnabled.setText(_translate("DockWidget", "Unchecked"))
        self.checkBoxUncheckedDis.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.checkBoxUncheckedDis.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.checkBoxUncheckedDis.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.checkBoxUncheckedDis.setText(_translate("DockWidget", "Unchecked"))
        self.label_31.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_31.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_31.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_31.setText(_translate("DockWidget", "CommandLinkButton"))
        self.commandLinkButton.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.commandLinkButton.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.commandLinkButton.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.commandLinkButton.setText(_translate("DockWidget", "Command"))
        self.commandLinkButtonDIs.setText(_translate("DockWidget", "Command"))
        self.label_32.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_32.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_32.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_32.setText(_translate("DockWidget", "ButtonBox"))
        self.buttonBox.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.buttonBox.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.buttonBox.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_36.setToolTip(_translate("DockWidget", "This is a tool tip"))
        self.label_36.setStatusTip(_translate("DockWidget", "This is a status tip"))
        self.label_36.setWhatsThis(_translate("DockWidget", "This is \"what is this\""))
        self.label_36.setText(_translate("DockWidget", "Inside DockWidget"))
        self.label.setText(_translate("DockWidget", "CheckBox"))
        self.checkBoxTristate.setText(_translate("DockWidget", "Tristate"))
        self.checkBoxTristateDis.setText(_translate("DockWidget", "Tristate"))




# -*- coding: utf-8 -*-
"""Script to process UI files (convert .ui to .py).

It compiles .ui files to be used with PyQt4, PyQt5, PySide, QtPy, PyQtGraph.
You just need to run (it has default values) from script folder.

To run this script you need to have these tools available on system:

    - pyuic4 for PyQt4 and PyQtGraph
    - pyuic5 for PyQt5 and QtPy
    - pyside-uic for Pyside
    - pyside2-uic for Pyside2

Links to understand those tools:

    - pyuic4: http://pyqt.sourceforge.net/Docs/PyQt4/designer.html#pyuic4
    - pyuic5: http://pyqt.sourceforge.net/Docs/PyQt5/designer.html#pyuic5
    - pyside-uic: https://www.mankier.com/1/pyside-uic
    - pyside2-uic: https://wiki.qt.io/Qt_for_Python_UiFiles (Documentation Incomplete)

"""

from __future__ import absolute_import, print_function

import argparse
import glob
import os
import sys
from subprocess import call


def main(arguments):
    """Process UI files."""
    parser = argparse.ArgumentParser(description=__doc__,
                                     formatter_class=argparse.RawDescriptionHelpFormatter)
    parser.add_argument('--ui_dir',
                        default='../example/ui',
                        type=str,
                        help="UI files directory, relative to current directory.",)
    parser.add_argument('--create',
                        default='all',
                        choices=['pyqt', 'pyqt5', 'pyside', 'pyside2', 'qtpy', 'pyqtgraph', 'all'],
                        type=str,
                        help="Choose which one would be generated.")

    args = parser.parse_args(arguments)

    print('Changing directory to: ', args.ui_dir)
    os.chdir(args.ui_dir)

    print('Converting .ui to .py ...')

    for ui_file in glob.glob('*.ui'):
        # get name without extension
        filename = os.path.splitext(ui_file)[0]
        print(filename, '...')
        ext = '.py'

        # creating names
        py_file_pyqt5 = filename + '_pyqt5_ui' + ext
        py_file_pyqt = filename + '_pyqt_ui' + ext
        py_file_pyside = filename + '_pyside_ui' + ext
        py_file_pyside2 = filename + '_pyside2_ui' + ext
        py_file_qtpy = filename + '_qtpy_ui' + ext
        py_file_pyqtgraph = filename + '_pyqtgraph_ui' + ext

        # calling external commands
        if args.create in ['pyqt', 'pyqtgraph', 'all']:
            try:
                call(['pyuic4', '--from-imports', ui_file, '-o', py_file_pyqt])
            except Exception as er:
                print("You must install pyuic4 %s" % str(er))
            else:
                print("Compiling using pyuic4 ...")

        if args.create in ['pyqt5', 'qtpy', 'all']:
            try:
                call(['pyuic5', '--from-imports', ui_file, '-o', py_file_pyqt5])
            except Exception as er:
                print("You must install pyuic5 %s" % str(er))
            else:
                print("Compiling using pyuic5 ...")

        if args.create in ['pyside', 'all']:
            try:
                call(['pyside-uic', '--from-imports', ui_file, '-o', py_file_pyside])
            except Exception as er:
                print("You must install pyside-uic %s" % str(er))
            else:
                print("Compiling using pyside-uic ...")

        if args.create in ['pyside2', 'all']:
            try:
                call(['pyside2-uic', '--from-imports', ui_file, '-o', py_file_pyside2])
            except Exception as er:
                print("You must install pyside2-uic %s" % str(er))
            else:
                print("Compiling using pyside2-uic ...")

        if args.create in ['qtpy', 'all']:
            print("Creating also for qtpy ...")
            # special case - qtpy - syntax is PyQt5
            with open(py_file_pyqt5, 'r') as file:
                filedata = file.read()
            # replace the target string
            filedata = filedata.replace('from PyQt5', 'from qtpy')
            with open(py_file_qtpy, 'w+') as file:
                # write the file out again
                file.write(filedata)

        if args.create in ['pyqtgraph', 'all']:
            print("Creating also for pyqtgraph ...")
            # special case - pyqtgraph - syntax is PyQt4
            with open(py_file_pyqt, 'r') as file:
                filedata = file.read()
            # replace the target string
            filedata = filedata.replace('from PyQt4', 'from pyqtgraph.Qt')
            with open(py_file_pyqtgraph, 'w+') as file:
                # write the file out again
                file.write(filedata)


if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_views.ui'
#
# Created: Thu Dec 13 17:14:06 2018
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName("DockWidget")
        DockWidget.resize(266, 387)
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName("gridLayout")
        self.label_70 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_70.setFont(font)
        self.label_70.setObjectName("label_70")
        self.gridLayout.addWidget(self.label_70, 0, 1, 1, 1)
        self.label_80 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_80.setFont(font)
        self.label_80.setObjectName("label_80")
        self.gridLayout.addWidget(self.label_80, 0, 2, 1, 1)
        self.label_27 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_27.setFont(font)
        self.label_27.setObjectName("label_27")
        self.gridLayout.addWidget(self.label_27, 1, 0, 1, 1)
        self.listView = QtGui.QListView(self.dockWidgetContents)
        self.listView.setObjectName("listView")
        self.gridLayout.addWidget(self.listView, 1, 1, 1, 1)
        self.listViewDis = QtGui.QListView(self.dockWidgetContents)
        self.listViewDis.setEnabled(False)
        self.listViewDis.setObjectName("listViewDis")
        self.gridLayout.addWidget(self.listViewDis, 1, 2, 1, 1)
        self.label_59 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_59.setFont(font)
        self.label_59.setObjectName("label_59")
        self.gridLayout.addWidget(self.label_59, 2, 0, 1, 1)
        self.treeView = QtGui.QTreeView(self.dockWidgetContents)
        self.treeView.setObjectName("treeView")
        self.gridLayout.addWidget(self.treeView, 2, 1, 1, 1)
        self.treeViewDis = QtGui.QTreeView(self.dockWidgetContents)
        self.treeViewDis.setEnabled(False)
        self.treeViewDis.setObjectName("treeViewDis")
        self.gridLayout.addWidget(self.treeViewDis, 2, 2, 1, 1)
        self.label_60 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_60.setFont(font)
        self.label_60.setObjectName("label_60")
        self.gridLayout.addWidget(self.label_60, 3, 0, 1, 1)
        self.tableView = QtGui.QTableView(self.dockWidgetContents)
        self.tableView.setObjectName("tableView")
        self.gridLayout.addWidget(self.tableView, 3, 1, 1, 1)
        self.tableViewDis = QtGui.QTableView(self.dockWidgetContents)
        self.tableViewDis.setEnabled(False)
        self.tableViewDis.setObjectName("tableViewDis")
        self.gridLayout.addWidget(self.tableViewDis, 3, 2, 1, 1)
        self.label_61 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_61.setFont(font)
        self.label_61.setObjectName("label_61")
        self.gridLayout.addWidget(self.label_61, 4, 0, 1, 1)
        self.columnView = QtGui.QColumnView(self.dockWidgetContents)
        self.columnView.setObjectName("columnView")
        self.gridLayout.addWidget(self.columnView, 4, 1, 1, 1)
        self.columnViewDis = QtGui.QColumnView(self.dockWidgetContents)
        self.columnViewDis.setEnabled(False)
        self.columnViewDis.setObjectName("columnViewDis")
        self.gridLayout.addWidget(self.columnViewDis, 4, 2, 1, 1)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(QtGui.QApplication.translate("DockWidget", "Views", None, QtGui.QApplication.UnicodeUTF8))
        self.label_70.setText(QtGui.QApplication.translate("DockWidget", "Enabled", None, QtGui.QApplication.UnicodeUTF8))
        self.label_80.setText(QtGui.QApplication.translate("DockWidget", "Disabled", None, QtGui.QApplication.UnicodeUTF8))
        self.label_27.setText(QtGui.QApplication.translate("DockWidget", "ListView", None, QtGui.QApplication.UnicodeUTF8))
        self.label_59.setText(QtGui.QApplication.translate("DockWidget", "TreeView", None, QtGui.QApplication.UnicodeUTF8))
        self.label_60.setText(QtGui.QApplication.translate("DockWidget", "TableView", None, QtGui.QApplication.UnicodeUTF8))
        self.label_61.setText(QtGui.QApplication.translate("DockWidget", "ColunmView", None, QtGui.QApplication.UnicodeUTF8))




import sys
from datetime import datetime
mycall="K1JT"
mygrid="FN20"

# Keyed with hiscall:
Freq={}
T0={}
RcvdExch={}
Grid={}

# Keyed with hiscall_band:
Staged={}
TimeLogged={}
QSOinProgress={}
# QSOinProgress bit values:
#  1 He called me
#  2 I called him
#  4 Received his exchange
#  8 Received his Roger
# 16 Sent Roger
# 32 Staged for logging

def isGrid(g):
    """Return True if g is a valid grid4 and not RR73"""
    if len(g)!=4 or g=="RR73": return False
    if ord(g[0:1])<ord('A') or ord(g[0:1])>ord('R'): return False
    if ord(g[1:2])<ord('A') or ord(g[1:2])>ord('R'): return False
    if ord(g[2:3])<ord('0') or ord(g[2:3])>ord('9'): return False
    if ord(g[3:4])<ord('0') or ord(g[3:4])>ord('9'): return False
    return True

if len(sys.argv)!=4:
    print "Usage:   python all2cab.py <mycall> <mygrid> <infile>"
    print "Example: python all2cab.py K1JT FN20 all_wwdigi_2019.txt"
    exit()

f=open(sys.argv[3],mode='r')
ss=f.readlines()
f.close
dt0=datetime.strptime(ss[0][0:13],"%y%m%d_%H%M%S")
iz=len(ss)
nqso=0
hiscall_band=""

for i in range(iz):
    s=ss[i][0:80].strip()
    dt=datetime.strptime(s[0:13],"%y%m%d_%H%M%S")
    tx=" Tx " in s              #True if this is my transmission
    w=s.split()
    if len(w)<10: continue
    if w[7]=="CQ":
        cq=True
        if w[8].isalpha():
            s=s.replace(" CQ "," CQ_")
            w=s.split()
    if len(w)<10: continue
    c1=w[7]
    c2=w[8]
    c3=w[9]
    roger = c3=="R"
    if roger: c3=w[10]
    cq = (c1=="CQ" or c1[0:3]=="CQ_")
    if cq:
        Grid[c2]=c3

    hiscall=""
    if tx and not cq:
        hiscall=c1
    if c1==mycall:
        freq=int(1000.0*float(s[13:23])) + int((int(s[42:47]))/1000)
        hiscall=c2
        Freq[hiscall]=freq
        MHz="%3d" % int(float(s[13:23]))
        hiscall_band=hiscall+MHz
        n=QSOinProgress.get(hiscall_band,0)
        n = n | 1                                 #He called me
        if roger or c3=="RR73" or c3=="RRR" or c3=="73":
            n = n | 8                             # Rcvd Roger
        if isGrid(c3):
            hisgrid=c3
            RcvdExch[hiscall]=hisgrid
            n = n | 4                             #Received his exchange
        else:
            g=Grid.get(hiscall,"")
            if isGrid(g):
                RcvdExch[hiscall]=g
                n = n | 4                         #Received his exchange
        QSOinProgress[hiscall_band]=n
        
    if len(hiscall)>=3:
        MHz="%3d" % int(float(s[13:23]))
        hiscall_band=hiscall+MHz
        if tx:
            n=QSOinProgress.get(hiscall_band,0)
            n = n | 2                             #I called him
            if roger or c3=="RR73" or c3=="RRR" or c3=="73":
                n = n | 4 | 16                    #Rcvd Exch, Sent Roger
            if c3=="RR73" or c3=="RRR" or c3=="73":
                n = n | 8                         #Rcvd Exch, Sent Roger
            QSOinProgress[hiscall_band]=n
        T0[hiscall]=dt

    if len(hiscall_band)<5 or len(hiscall)<3: continue
    
    if QSOinProgress.get(hiscall_band,0)>=31:
        n=QSOinProgress.get(hiscall_band,0)
        n = n | 32
        QSOinProgress[hiscall_band]=n
        t=str(T0[hiscall])[0:16]
        t=t[0:13] + t[14:16]
        buf="QSO: %5d DG %s %-10s    %s       %-10s    %s" % (Freq[hiscall],t,\
                mycall,mygrid,hiscall,RcvdExch.get(hiscall,"    "))
        MHz="%3d" % int(float(s[13:23]))
        hiscall_band=hiscall+MHz
        t=Staged.get(hiscall_band,"")
        time_diff=-1
        if TimeLogged.get(hiscall_band,0)!=0:
            time_diff=(T0[hiscall] - TimeLogged[hiscall_band]).total_seconds()
        if time_diff == -1 or time_diff > 180:    #Log only once within 3 min
            Staged[hiscall_band]=buf              #Staged for logging
            nqso=nqso+1
            TimeLogged[hiscall_band]=T0[hiscall]
            print buf                             #For now, log anything staged
            del QSOinProgress[hiscall_band]
